@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.server;
 
+import java.util.ConcurrentModificationException;
+import java.util.concurrent.atomic.AtomicBoolean;
+
+import org.apache.activemq.artemis.api.core.ActiveMQException;
 import org.apache.activemq.artemis.api.core.Message;
 import org.apache.activemq.artemis.api.core.QueueConfiguration;
 import org.apache.activemq.artemis.api.core.SimpleString;
@@ -33,6 +37,7 @@ import org.apache.activemq.artemis.core.server.impl.LastValueQueue;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.tests.util.Wait;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.RetryMethod;
 import org.apache.activemq.artemis.utils.RetryRule;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
@@ -140,6 +145,28 @@ public class LVQTest extends ActiveMQTestBase {
       Assert.assertEquals(m.getBodyBuffer().readString(), "m4");
    }
 
+   @Test
+   public void testMultipleMessagesWithoutLastValue() throws Exception {
+      ClientProducer producer = clientSession.createProducer(address);
+      ClientMessage m1 = createTextMessage(clientSession, "message1");
+      ClientMessage m2 = createTextMessage(clientSession, "message2");
+      producer.send(m1);
+      producer.send(m2);
+
+      Wait.assertEquals(2L, () -> server.locateQueue(qName1).getMessageCount(), 2000, 100);
+
+      ClientConsumer consumer = clientSession.createConsumer(qName1);
+      clientSession.start();
+      ClientMessage m = consumer.receive(1000);
+      Assert.assertNotNull(m);
+      m.acknowledge();
+      Assert.assertEquals("message1", m.getBodyBuffer().readString());
+      m = consumer.receive(1000);
+      Assert.assertNotNull(m);
+      m.acknowledge();
+      Assert.assertEquals("message2", m.getBodyBuffer().readString());
+   }
+
    @Test
    public void testMultipleRollback() throws Exception {
       AddressSettings qs = new AddressSettings();
@@ -807,6 +834,72 @@ public class LVQTest extends ActiveMQTestBase {
       assertEquals(queue.getDeliveringSize(), 0);
    }
 
+   @Test
+   public void testConcurrency() throws Exception {
+      AtomicBoolean cme = new AtomicBoolean(false);
+
+      AtomicBoolean hash = new AtomicBoolean(true);
+      Queue lvq = server.locateQueue(qName1);
+      Thread hashCodeThread = new Thread(() -> {
+         while (hash.get()) {
+            try {
+               int hashCode = lvq.hashCode();
+            } catch (ConcurrentModificationException e) {
+               cme.set(true);
+               return;
+            }
+         }
+      });
+      hashCodeThread.start();
+
+      AtomicBoolean consume = new AtomicBoolean(true);
+      ClientConsumer consumer = clientSessionTxReceives.createConsumer(qName1);
+      clientSessionTxReceives.start();
+      Thread consumerThread = new Thread(() -> {
+         while (consume.get()) {
+            try {
+               ClientMessage m = consumer.receive();
+               m.acknowledge();
+               clientSessionTxReceives.commit();
+            } catch (ActiveMQException e) {
+               e.printStackTrace();
+               return;
+            }
+         }
+      });
+      consumerThread.start();
+
+      ClientProducer producer = clientSessionTxSends.createProducer(address);
+      SimpleString lastValue = RandomUtil.randomSimpleString();
+      AtomicBoolean produce = new AtomicBoolean(true);
+      Thread producerThread = new Thread(() -> {
+         for (int i = 0; !cme.get() && produce.get(); i++) {
+            ClientMessage m = createTextMessage(clientSession, "m" + i, false);
+            m.putStringProperty(Message.HDR_LAST_VALUE_NAME, lastValue);
+            try {
+               producer.send(m);
+               clientSessionTxSends.commit();
+            } catch (ActiveMQException e) {
+               e.printStackTrace();
+               return;
+            }
+         }
+      });
+      producerThread.start();
+      producerThread.join(5000);
+
+      try {
+         assertFalse(cme.get());
+      } finally {
+         produce.set(false);
+         producerThread.join();
+         consume.set(false);
+         consumerThread.join();
+         hash.set(false);
+         hashCodeThread.join();
+      }
+   }
+
    @Override
    @Before
    public void setUp() throws Exception {
